@@ -1,11 +1,14 @@
 # pylint: disable=W0611
 from typing import List, Literal, Optional, Union
 
-from pydantic import BaseModel, Extra
+from pydantic import BaseModel, ConfigDict
 
 from .components import Components
 from .external_documentation import ExternalDocumentation
 from .info import Info
+
+# Required to update forward ref after object creation
+from .path_item import PathItem
 from .paths import Paths
 from .security_requirement import SecurityRequirement
 from .server import Server
@@ -27,7 +30,8 @@ class OpenAPI(BaseModel):
     security: Optional[List[SecurityRequirement]] = None
     tags: Optional[List[Tag]] = None
     externalDocs: Optional[ExternalDocumentation] = None
-    openapi: 'Union[Literal["3.0.0"], Literal["3.0.1"], Literal["3.0.2"], Literal["3.0.3"]]'
+    openapi: Union[Literal["3.0.0"], Literal["3.0.1"], Literal["3.0.2"], Literal["3.0.3"]]
+    model_config = ConfigDict(extra="allow")
 
-    class Config:  # pylint: disable=missing-class-docstring
-        extra = Extra.allow
+
+OpenAPI.model_rebuild()
